new_solutions_generated
Replace population with individuals chosen from population
Specification
Alias: None
Arguments: INTEGER
Default: population_size - replacement_size
Description
The
randomsetting creates a new population using (a)replacement_sizerandomly selected individuals from the current population, and (b)population_size-replacement_sizeindividuals randomly selected from among the newly generated individuals (the number of which is optionally specified usingnew_solutions_generated) that are created for each generation (using the selection, crossover, and mutation procedures).