demo_tpl

Third-party optimization library integration demonstration.

Specification

  • Alias: None

  • Arguments: None

Child Keywords:

Required/Optional

Description of Group

Dakota Keyword

Dakota Keyword Description

Optional

id_method

Name the method block; helpful when there are multiple

Optional

output

Control how much method information is written to the screen and output file

Optional

final_solutions

Number of designs returned as the best solutions

Optional

max_function_evaluations

Number of function evaluations allowed for optimizers

Optional

max_iterations

Number of iterations allowed for optimizers and adaptive UQ methods

Optional

convergence_tolerance

Stopping criterion based on objective function or statistics convergence

Optional

variable_tolerance

Step length-based stopping criteria for derivative-free optimizers

Optional

solution_target

Stopping criteria based on objective function value

Optional

options_file

Filename for a YAML file that specifies Gaussian process options

Description