num_bins

Number of bins used to compute the variance-based decomposition

Specification

  • Alias: None

  • Arguments: INTEGER

  • Default: -1

Description

Allows the user to specify the number of bins to be used in the variance-based decomposition.

Default Behavior For continuous variables, the default number of bins is the square root of the number of samples rounded down to the nearest integer. For discrete and categorical variables, the number of bins is equal to the number of unique values the variable takes in the sample set.

Examples

method,
  sampling
    sample_type lhs
    samples = 100
    variance_based_decomp
      vbd_method binned
        num_bins = 10

Theory

The binned approach to computing Sobol’ main effect indices is introduced in [LM16]. As opposed to pick-and-freeze approaches like [STCR04], it does not require a specific sampling structure. Given a set of randomly-generated input-output samples, it computes the main effect index by binning samples, computing a sample statistic for each bin, then computing another sample statistic over the bins.

The number of bins recommended in [LM16] is the square root of the number of input-output samples. This is the default number of bins used for the method in Dakota. However, if the user wishes to specify a different number of bins, they can do so using num_bins.