generating_matrices
Specify the generating matrices of this digital net
Specification
Alias: None
Arguments: None
Default: Predfined generating matrices from Joe and Kuo (2008)
Child Keywords:
Required/Optional |
Description of Group |
Dakota Keyword |
Dakota Keyword Description |
|---|---|---|---|
Required (Choose One) |
Generating Matrices |
Specify inline generating matrices |
|
Specify generating matrices read from file |
|||
Specify predefined generating matrices |
Description
There are three ways in which a user can specify generating matrices:
inline generating matrices (with the keyword
inline)generating matrices read from an external file (with the keyword
file)predefined generating matrices (with the keyword
predefined)
One of these options must be specified if the generating_matrices keyword is provided.