generating_vector
Specify the generating vector of this rank-1 lattice rule
Specification
Alias: None
Arguments: None
Default: No generating vector
Child Keywords:
Required/Optional |
Description of Group |
Dakota Keyword |
Dakota Keyword Description |
|---|---|---|---|
Required (Choose One) |
Generating Vector |
Specify an inline generating vector |
|
Specify a generating vector read from file |
|||
Specify a predefined generating vector |
Description
There are three ways in which a user can specify a generating vector:
an inline generating vector (with the keyword
inline)a generating vector read from an external file (with the keyword
file)a predefined generating vector (with the keyword
predefined)
One of these options must be specified if the generating_vector keyword is provided.