best_fitness_tracker
Tracks the best fitness of the population
Specification
Alias: None
Arguments: None
Child Keywords:
Required/Optional |
Description of Group |
Dakota Keyword |
Dakota Keyword Description |
|---|---|---|---|
Optional |
Define the convergence criterion for JEGA methods |
||
Optional |
Define the convergence criterion for JEGA methods |
||
Description
The best_fitness_tracker tracks the best fitness in the
population. Convergence occurs after num_generations has passed and
there has been less than percent_change in the best fitness
value. The percent change can be as low as 0% in which case there must
be no change at all over the number of generations.