parameters
Select a parmaterization of the lognormal distribution
Specification
Alias: None
Arguments: None
Child Keywords:
Required/Optional |
Description of Group |
Dakota Keyword |
Dakota Keyword Description |
|---|---|---|---|
Required (Choose One) |
Lognormal parameterization selection |
Specify means and standard deviations for the lognormal distributions |
|
Specify means and error factors for the lognormal distributions |
|||
Specify lambdas and zetas for the lognormal distributions |
Description
Lognormal variables must be parameterized in one of three ways:
option_1: mean and standard deviation
option_2: mean and error factor
option_3: lambda and zeta
This keyword anchors that selection.