means

First parameter of the lognormal distribution (options 1 & 2)

Specification

  • Alias: lnuv_means

  • Arguments: REALLIST

Description

For the lognormal variables, one may specify either the mean \(\mu\) and standard deviation \(\sigma\) of the actual lognormal distribution, the mean \(\mu\) and error factor \(\epsilon\) of the actual lognormal distribution.

This corresponds to the mean of the lognormal random variable