conmin_frcg
CONMIN conjugate gradient optimization method
Specification
Alias: None
Arguments: None
Child Keywords:
Required/Optional |
Description of Group |
Dakota Keyword |
Dakota Keyword Description |
|---|---|---|---|
Optional |
Name the method block; helpful when there are multiple |
||
Optional |
Control how much method information is written to the screen and output file |
||
Optional |
Number of designs returned as the best solutions |
||
Optional |
Number of iterations allowed for optimizers and adaptive UQ methods |
||
Optional |
Stopping criterion based on objective function or statistics convergence |
||
Optional |
Maximum allowable constraint violation still considered feasible |
||
Optional |
Compute speculative gradients |
||
Optional |
Number of function evaluations allowed for optimizers |
||
Optional |
Turn on scaling for variables, responses, and constraints |
||
Optional |
Identifier for model block to be used by a method |
||
Description
The interpretations of the method independent controls for CONMIN are essentially identical to those for DOT.
See Package: CONMIN for information related to CONMIN
methods.
Expected HDF5 Output
If Dakota was built with HDF5 support and run with the
hdf5 keyword, this method
writes the following results to HDF5:
Best Objective Functions (when
objective_functions) are specified)Calibration (when
calibration_termsare specified)