dl_solver
(Experimental) Dynamically-loaded solver
Topics
optimization_and_calibration
Specification
Alias: None
Arguments: STRING
Child Keywords:
Required/Optional |
Description of Group |
Dakota Keyword |
Dakota Keyword Description |
|---|---|---|---|
Optional |
Name the method block; helpful when there are multiple |
||
Optional |
Control how much method information is written to the screen and output file |
||
Optional |
Number of designs returned as the best solutions |
||
Optional |
Number of function evaluations allowed for optimizers |
||
Optional |
Turn on scaling for variables, responses, and constraints |
||
Optional |
Identifier for model block to be used by a method |
||
Description
This keyword specifies a dynamically-loaded optimization solver library, an experimental Dakota feature that is not enabled by default.