model_reordering
Approach for addressing model misordering during numerical solutions.
Specification
Alias: None
Arguments: None
Child Keywords:
Required/Optional |
Description of Group |
Dakota Keyword |
Dakota Keyword Description |
|---|---|---|---|
Required (Choose One) |
Model reordering |
Address any model misordering in MFMC numerical solutions by reordering on the fly. |
|
Enforce a prescribed model ordering in MFMC numerical solutions through additional linear constraints. |
Description
Multifidelity Monte Carlo is a hierarchical sampling method that
requires an ordered set of model approximations, whether in terms of
model response correlations (for analytic solutions) or model sample
allocations (for estimator variance calculations in numerical
solutions). In the latter case of numerical solutions, ordering of
sample allocations can be accomplished using two different approaches,
either reordering on the fly (auto_reorder) as dictated by a given
set of allocations or enforcing a prescribed model ordering
(fixed_order) through additional linear constraints on the
numerical solution.