auto_reorder
Address any model misordering in MFMC numerical solutions by reordering on the fly.
Specification
Alias: None
Arguments: None
Description
The ordering of the model hierarchy is continuously redefined as needed to allow for proper evaluation of MFMC estimator variance expressions. The specified model order in the ensemble surrogate model specification is only used as the starting point for the algorithm.
On-the-fly model reordering can result in lower estimator variance, but it can affect solution robustness (due to discontinuous gradients) and complicate comparisons with published MFMC implementations. The use of global-local numerical solver selections can mitigate the first concern to a degree.
Examples
method,
multifidelity_sampling
numerical_solve override
global_local
model_reordering auto_reorder # default approach
solution_mode online_pilot
pilot_samples = 50 seed = 8674132
max_function_evaluations = 500